[debhelper-devel] [RFC 2/4] dh_auto_* prints upstream build system commands run unless DH_QUIET is set

Bernhard R. Link brlink at debian.org
Mon Dec 29 12:35:52 UTC 2014


Signed-off-by: Bernhard R. Link <brlink at debian.org>
---
 Debian/Debhelper/Buildsystem.pm | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/Debian/Debhelper/Buildsystem.pm b/Debian/Debhelper/Buildsystem.pm
index 8fde215..e787363 100644
--- a/Debian/Debhelper/Buildsystem.pm
+++ b/Debian/Debhelper/Buildsystem.pm
@@ -294,35 +294,35 @@ sub _cd {
 }
 
 # Changes working directory to the source directory (if needed),
 # calls doit(@_) and changes working directory back to the top
 # directory.
 sub doit_in_sourcedir {
 	my $this=shift;
 	if ($this->get_sourcedir() ne '.') {
 		my $sourcedir = $this->get_sourcedir();
 		$this->_cd($sourcedir);
-		doit(@_);
+		print_and_doit(@_);
 		$this->_cd($this->_rel2rel($this->{cwd}, $sourcedir));
 	}
 	else {
-		doit(@_);
+		print_and_doit(@_);
 	}
 	return 1;
 }
 
 # Changes working directory to the build directory (if needed),
 # calls doit(@_) and changes working directory back to the top
 # directory.
 sub doit_in_builddir {
 	my $this=shift;
 	if ($this->get_buildpath() ne '.') {
 		my $buildpath = $this->get_buildpath();
 		$this->_cd($buildpath);
-		doit(@_);
+		print_and_doit(@_);
 		$this->_cd($this->_rel2rel($this->{cwd}, $buildpath));
 	}
 	else {
-		doit(@_);
+		print_and_doit(@_);
 	}
 	return 1;
 }
@@ -294,35 +294,35 @@ sub _cd {
 
 # Changes working directory to the source directory (if needed),
-# calls doit(@_) and changes working directory back to the top
-# directory.
+# calls print_and_doit(@_) and changes working directory back to the
+# top directory.
 sub doit_in_sourcedir {
 	my $this=shift;
@@ -294,35 +294,35 @@ sub _cd {
 
 # Changes working directory to the build directory (if needed),
-# calls doit(@_) and changes working directory back to the top
-# directory.
+# calls print_and_doit(@_) and changes working directory back to the
+# top directory.
 sub doit_in_builddir {
 	my $this=shift;
-- 
2.1.4

	Bernhard R. Link
-- 
F8AC 04D5 0B9B 064B 3383  C3DA AFFC 96D1 151D FFDC



More information about the debhelper-devel mailing list